==> temando-module-shipping-m2-1.3.10.zip: Webservice/Processor/OrderOperation/RatesProcessor.php <==
<?php
/**
 * Refer to LICENSE.txt distributed with the Temando Shipping module for notice of license
 */
namespace Temando\Shipping\Webservice\Processor\OrderOperation;

use Magento\Framework\Exception\CouldNotSaveException;
use Magento\Quote\Model\Quote\Address\RateRequest;
use Temando\Shipping\Api\Data\Order\ShippingExperienceInterface;
use Temando\Shipping\Model\OrderInterface;
use Temando\Shipping\Webservice\Response\Type\OrderResponseTypeInterface;

/**
 * Temando Rates Processor.
 *
 * @package Temando\Shipping\Webservice
 * @author  Christoph Aßmann <christoph.assmann@netresearch.de>
 * @license http://opensource.org/licenses/osl-3.0.php Open Software License (OSL 3.0)
 * @link    http://www.temando.com/
 */
class RatesProcessor implements RatesProcessorInterface
{
    /**
     * Extract shipping experiences from response.
     *
     * @param RateRequest $rateRequest
     * @param OrderInterface $requestType
     * @param OrderResponseTypeInterface $responseType
     * @return ShippingExperienceInterface[]
     */
    public function postProcess(
        RateRequest $rateRequest,
        OrderInterface $requestType,
        OrderResponseTypeInterface $responseType
    ) {
        $collectionPointId = $requestType->getCollectionPoint()->getCollectionPointId();
        if ($collectionPointId) {
            // ignore default recipient address experiences
            return [];
        }

        // experiences for default addresses
        $experiences = $responseType->getShippingExperiences();

        return $experiences;
    }
}

==> temando-module-shipping-m2-1.4.0.zip: Webservice/Processor/OrderOperation/RatesProcessor.php <==
<?php
/**
 * Refer to LICENSE.txt distributed with the Temando Shipping module for notice of license
 */
namespace Temando\Shipping\Webservice\Processor\OrderOperation;

use Magento\Quote\Model\Quote\Address\RateRequest;
use Temando\Shipping\Api\Data\Order\ShippingExperienceInterface;
use Temando\Shipping\Model\OrderInterface;
use Temando\Shipping\Webservice\Response\Type\OrderResponseTypeInterface;

/**
 * Temando Rates Processor.
 *
 * @package Temando\Shipping\Webservice
 * @author  Christoph Aßmann <christoph.assmann@netresearch.de>
 * @license https://opensource.org/licenses/osl-3.0.php Open Software License (OSL 3.0)
 * @link    https://www.temando.com/
 */
class RatesProcessor implements RatesProcessorInterface
{
    /**
     * Extract shipping experiences from response.
     *
     * @param RateRequest $rateRequest
     * @param OrderInterface $requestType
     * @param OrderResponseTypeInterface $responseType
     * @return ShippingExperienceInterface[]
     */
    public function postProcess(
        RateRequest $rateRequest,
        OrderInterface $requestType,
        OrderResponseTypeInterface $responseType
    ) {
        $collectionPointId = $requestType->getCollectionPoint()->getCollectionPointId();
        $pickupLocationId = $requestType->getPickupLocation()->getPickupLocationId();
        if ($collectionPointId || $pickupLocationId) {
            // ignore default recipient address experiences
            return [];
        }

        // experiences for default addresses
        $experiences = $responseType->getShippingExperiences();

        return $experiences;
    }
}
